summaryrefslogtreecommitdiffstats
path: root/chalk/ui/kis_part_layer.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/ui/kis_part_layer.cc')
-rw-r--r--chalk/ui/kis_part_layer.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/chalk/ui/kis_part_layer.cc b/chalk/ui/kis_part_layer.cc
index 5846a67b..ace29965 100644
--- a/chalk/ui/kis_part_layer.cc
+++ b/chalk/ui/kis_part_layer.cc
@@ -94,19 +94,19 @@ void KisPartLayerImpl::childActivated(KoDocumentChild* child)
// Called when another layer is made inactive
void KisPartLayerImpl::childDeactivated(bool activated)
{
// We probably changed, notify the image that it needs to repaint where we currently updated
// We use the original geometry
if (m_activated && !activated /* no clue, but debugging suggests it is false here */) {
TQPtrList<KoView> views = m_doc->parentDocument()->views();
Q_ASSERT(views.count());
views.at(0)->disconnect(TQT_SIGNAL(activated(bool)));
m_activated = false;
- setDirty(m_doc->geometry());
+ setDirty(m_doc->tqgeometry());
}
}
void KisPartLayerImpl::setX(TQ_INT32 x) {
- TQRect rect = m_doc->geometry();
+ TQRect rect = m_doc->tqgeometry();
// KisPaintDevice::move moves to absolute coordinates, not relative. Work around that here,
// since the part is not necesarily started at (0,0)
@@ -115,7 +115,7 @@ void KisPartLayerImpl::setX(TQ_INT32 x) {
}
void KisPartLayerImpl::setY(TQ_INT32 y) {
- TQRect rect = m_doc->geometry();
+ TQRect rect = m_doc->tqgeometry();
// KisPaintDevice::move moves to absolute coordinates, not relative. Work around that here,
// since the part is not necesarily started at (0,0)
@@ -125,7 +125,7 @@ void KisPartLayerImpl::setY(TQ_INT32 y) {
void KisPartLayerImpl::paintSelection(TQImage &img, TQ_INT32 x, TQ_INT32 y, TQ_INT32 w, TQ_INT32 h) {
uchar *j = img.bits();
- TQRect rect = m_doc->geometry();
+ TQRect rect = m_doc->tqgeometry();
for (int y2 = y; y2 < h + y; ++y2) {
for (int x2 = x; x2 < w + x; ++x2) {
@@ -94,19 +94,19 @@ void KisPartLayerImpl::childActivated(KoDocumentChild* child)
void KisPartLayerImpl::childDeactivated(bool activated)
{
- // We probably changed, notify the image that it needs to repaint where we currently updated
- // We use the original geometry
+ // We probably changed, notify the image that it needs to tqrepaint where we currently updated
+ // We use the original tqgeometry
if (m_activated && !activated /* no clue, but debugging suggests it is false here */) {
TQPtrList<KoView> views = m_doc->parentDocument()->views();